/*
 * Web Designer
 * Copyright (C) 1999-2000  LADISLAS Willhem
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * Author's email : zillprog@freesurf.fr
 * 
 * snailmail : 
 * LADISLAS Willhem
 * 2, rue du Serpolet
 * 95490 VAUREAL
 * FRANCE
 */

/*
 * get_main_menu - gettext support hacked in by Gergely Nagy
 * The rest of this file is taken from webdesigner.c from the
 * original 0.1.1 source package.
 */

#include "common_headers.h"

static GtkItemFactoryEntry menu_items_base[] =
{
	{N_ ("/_File"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/File/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/File/_New"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/File/New/ftt"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/File/New/Html document"), "<alt>N", new_html_file, 0, NULL},
	{N_ ("/File/New/Text document"), NULL, newfile, 0, NULL},
	{N_ ("/File/_Open..."), "<control>O", openfile, 0, NULL},
	{N_ ("/File/_Close"), "<control>W", close_primary, 0, NULL},
	{N_ ("/File/Close all"), NULL, close_all_files, 0, NULL},
	{N_ ("/File/sep1"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/File/_Save"), "<control>S", savefile, 0, NULL},
	{N_ ("/File/Save as..."), NULL, dialogsaveas, 0, NULL},
	{N_ ("/File/sep2"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/File/Import..."), NULL, import_file_dialog, 0, NULL},
	{N_ ("/File/Information..."), NULL, display_file_info, 0, NULL},
	{N_ ("/File/_Print..."), NULL, print_file, 0, NULL},
	{N_ ("/File/sep3"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/File/_Quit"), "<control>Q", close_application, 0, NULL},
	{N_ ("/File/scp"), NULL, NULL, 0, "<Separator>"},

	{N_ ("/_Edit"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Edit/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Edit/Cut"), "<control>X", clipboard_actions, CLIPBOARD_CUT, NULL},
	{N_ ("/Edit/_Copy"), "<control>C", clipboard_actions, CLIPBOARD_COPY, NULL},
	{N_ ("/Edit/Paste"), "<control>V", clipboard_actions, CLIPBOARD_PASTE, NULL},
	{N_ ("/Edit/se4"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Edit/Paste in new doc"), NULL, clipboard_actions, CLIPBOARD_PASTE_AS_NEW, NULL},
	{N_ ("/Edit/Compact HTML tags"), NULL, compact_file, COMPACT_NEWLINES, NULL},
	{N_ ("/Edit/Replace special chars"), NULL, compact_file, COMPACT_REPLACE_CHARS, NULL},
	{N_ ("/Edit/Remove all tags"), NULL, remove_tags, 0, NULL},
	{N_ ("/Edit/sep4"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Edit/Select _All"), "<alt>A", clipboard_actions, CLIPBOARD_SELECT_ALL, NULL},
	{N_ ("/Edit/Erase selection"), NULL, clipboard_actions, CLIPBOARD_CLEAR, NULL},
	{N_ ("/Edit/Repeat last tag"), "<control>R", repeat_tag, 0, NULL},
	{N_ ("/Edit/sep5"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Edit/Go to line..."), "<control>L", go_line, 0, NULL},
	{N_ ("/Edit/Change selection case"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Edit/Change selection case/tt"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Edit/Change selection case/To lower"), NULL, change_selection_case, 0, NULL},
	{N_ ("/Edit/Change selection case/To upper"), NULL, change_selection_case, 1, NULL},

/*
 * {N_("/Edit/Insert date"), NULL, insert_date, 0, NULL}, 
 */

	{N_ ("/_Project"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Project/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Project/New"), NULL, new_project, 0, NULL},
	{N_ ("/Project/Open..."), NULL, open_project_dialog, 0, NULL},
	{N_ ("/Project/Close"), NULL, close_project, 0, NULL},
	{N_ ("/Project/sep6"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Project/Save"), NULL, save_project, PROJECT_SAVE, NULL},
	{N_ ("/Project/Save as..."), NULL, save_project, PROJECT_SAVE_AS, NULL},
	{N_ ("/Project/sep7"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Project/Project manager"), NULL, init_clist, 0, NULL},
	{N_ ("/Project/Open all project files"), NULL, open_all_prjfiles, 0, NULL},
	{N_ ("/Project/Close all project files"), NULL, close_all_prjfiles, 0, NULL},
	{N_ ("/Project/se7"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Project/Add a file..."), NULL, add_afile_prj_dialog, 0, NULL},
	{N_ ("/Project/Add current file"), NULL, add_file, 0, NULL},
	{N_ ("/Project/Remove current file"), NULL, remove_file, 0, NULL},

	{N_ ("/_Tags"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Tags/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Tags/Common"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Tags/Common/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Tags/Common/Font"), NULL, tag_insert_exec, TAG_FONT, ""},
	{N_ ("/Tags/Common/sep9"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Tags/Common/Heading"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Tags/Common/Heading/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Tags/Common/Heading/H1"), NULL, tag_insert_exec, TAG_H1, ""},
	{N_ ("/Tags/Common/Heading/H2"), NULL, tag_insert_exec, TAG_H2, ""},
	{N_ ("/Tags/Common/Heading/H3"), NULL, tag_insert_exec, TAG_H3, ""},
	{N_ ("/Tags/Common/Heading/H4"), NULL, tag_insert_exec, TAG_H4, ""},
	{N_ ("/Tags/Common/Heading/H5"), NULL, tag_insert_exec, TAG_H5, ""},
	{N_ ("/Tags/Common/Heading/H6"), NULL, tag_insert_exec, TAG_H6, ""},
	{N_ ("/Tags/Common/Text"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Tags/Common/Text/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Tags/Common/Text/Bold"), "<control>G", tag_insert_exec, TAG_B, ""},
	{N_ ("/Tags/Common/Text/Italic"), "<control>I", tag_insert_exec, TAG_I, ""},
	{N_ ("/Tags/Common/Text/Underlined"), "<alt>U", tag_insert_exec, TAG_U, ""},
	{N_ ("/Tags/Common/Text/Center"), "<control>M", tag_insert_exec, TAG_CENTER, ""},
	{N_ ("/Tags/Common/Text/Preformatted"), NULL, tag_insert_exec, TAG_PRE, ""},

	{N_ ("/Tags/Common/Paragraph"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Tags/Common/Paragraph/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Tags/Common/Paragraph/Left"), NULL, tag_insert_exec, TAG_P_LEFT, ""},
	{N_ ("/Tags/Common/Paragraph/Center"), NULL, tag_insert_exec, TAG_P_CENTER, ""},
	{N_ ("/Tags/Common/Paragraph/Right"), NULL, tag_insert_exec, TAG_P_RIGHT, ""},
	{N_ ("/Tags/Common/Paragraph/Justify"), NULL, tag_insert_exec, TAG_P_JUSTIFY, ""},
	{N_ ("/Tags/Common/Anchor"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Tags/Common/Anchor/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Tags/Common/Anchor/Internal"), NULL, tag_insert_exec, TAG_A_NAME, ""},
	{N_ ("/Tags/Common/Anchor/External"), NULL, tag_insert_exec, TAG_A_LOCAL, ""},

	{N_ ("/Tags/Common/sep10"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Tags/Common/Blockquote"), NULL, tag_insert_exec, TAG_BLOCKQUOTE, ""},
	{N_ ("/Tags/Common/Line Break"), NULL, tag_insert_exec, TAG_BR, ""},
	{N_ ("/Tags/Common/Comment"), NULL, insert_text_and_move_cursor, 500, ""},
	{N_ ("/Tags/Common/Horizontal ruler"), NULL, tag_insert_exec, TAG_HR, ""},
	{N_ ("/Tags/Common/Image"), NULL, tag_insert_exec, TAG_IMG, ""},
	{N_ ("/Tags/Common/Insert path"), NULL, dialog_insert_path, 0, ""},

	{N_ ("/Tags/Font"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Tags/Font/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Tags/Font/Big text"), NULL, tag_insert_exec, TAG_BIG, ""},
	{N_ ("/Tags/Font/Small text"), NULL, tag_insert_exec, TAG_SMALL, ""},
	{N_ ("/Tags/Font/Blinking text"), NULL, tag_insert_exec, TAG_BLINK, ""},
	{N_ ("/Tags/Font/sep11"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Tags/Font/Emphasis"), NULL, tag_insert_exec, TAG_EM, ""},
	{N_ ("/Tags/Font/Striked"), NULL, tag_insert_exec, TAG_STRIKE, ""},
	{N_ ("/Tags/Font/Superscript"), NULL, tag_insert_exec, TAG_SUP, ""},
	{N_ ("/Tags/Font/Subscript"), NULL, tag_insert_exec, TAG_SUB, ""},
	{N_ ("/Tags/Font/Teletype text"), NULL, tag_insert_exec, TAG_TT, ""},
	{N_ ("/Tags/Font/Keyboard text"), NULL, tag_insert_exec, TAG_KBD, ""},
	{N_ ("/Tags/Font/sep12"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Tags/Font/Listing"), NULL, tag_insert_exec, TAG_LISTING, ""},
	{N_ ("/Tags/Font/Code"), NULL, tag_insert_exec, TAG_CODE, ""},
	{N_ ("/Tags/Font/Cite"), NULL, tag_insert_exec, TAG_CITE, ""},

	{N_ ("/Tags/Page"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Tags/Page/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Tags/Page/HTML"), "<control>H", tag_insert_exec, TAG_HTML, ""},
	{N_ ("/Tags/Page/Head"), NULL, tag_insert_exec, TAG_HEAD, ""},
	{N_ ("/Tags/Page/Body"), NULL, tag_insert_exec, TAG_BODY, ""},
	{N_ ("/Tags/Page/Title"), NULL, tag_insert_exec, TAG_TITLE, ""},
	{N_ ("/Tags/Page/sep13"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Tags/Page/Meta informations"), NULL, load_meta_info, 0, ""},
	{N_ ("/Tags/Page/Banner"), NULL, tag_insert_exec, TAG_BANNER, ""},
	{N_ ("/Tags/Page/Document type"), NULL, init_doctypelist, 0, ""},
	{N_ ("/Tags/Page/sep14"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Tags/Page/Internal anchor"), NULL, tag_insert_exec, TAG_A_NAME, ""},
	{N_ ("/Tags/Page/Internal link"), NULL, tag_insert_exec, TAG_A_LOCAL, ""},
	{N_ ("/Tags/Page/Link to top"), NULL, tag_insert_exec, TAG_A_TOP, ""},

	{N_ ("/Tags/Form"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Tags/Form/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Tags/Form/Form"), NULL, tag_insert_exec, TAG_FORM, ""},
	{N_ ("/Tags/Form/Input"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Tags/Form/Input/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Tags/Form/Input/Hidden"), NULL, tag_insert_exec, TAG_INPUT_HIDDEN, ""},
	{N_ ("/Tags/Form/Input/Password"), NULL, tag_insert_exec, TAG_INPUT_PASSWORD, ""},
	{N_ ("/Tags/Form/Input/Text"), NULL, tag_insert_exec, TAG_INPUT_TEXT, ""},
	{N_ ("/Tags/Form/Input/Reset"), NULL, tag_insert_exec, TAG_INPUT_RESET, ""},
	{N_ ("/Tags/Form/Input/Submit"), NULL, tag_insert_exec, TAG_INPUT_SUBMIT, ""},
	{N_ ("/Tags/Form/Input/Hidden"), NULL, tag_insert_exec, TAG_INPUT_HIDDEN, ""},
	{N_ ("/Tags/Form/Button"), NULL, tag_insert_exec, TAG_BUTTON, ""},
	{N_ ("/Tags/Form/sep15"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Tags/Form/Checkbox"), NULL, tag_insert_exec, TAG_INPUT_CHECKBOX, ""},
	{N_ ("/Tags/Form/Radio"), NULL, tag_insert_exec, TAG_INPUT_RADIO, ""},
	{N_ ("/Tags/Form/Text area"), NULL, tag_insert_exec, TAG_TEXTAREA, ""},
	{N_ ("/Tags/Form/Fieldset"), NULL, tag_insert_exec, TAG_FIELDSET, ""},

	{N_ ("/Tags/Table"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Tags/Table/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Tags/Table/Table"), NULL, tag_insert_exec, TAG_TABLE, ""},
	{N_ ("/Tags/Table/Head"), NULL, tag_insert_exec, TAG_TH, ""},
	{N_ ("/Tags/Table/Row"), NULL, tag_insert_exec, TAG_TR, ""},
	{N_ ("/Tags/Table/Data"), NULL, tag_insert_exec, TAG_TD, ""},
	{N_ ("/Tags/Table/Caption"), NULL, tag_insert_exec, TAG_CAPTION, ""},

	{N_ ("/Tags/List"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Tags/List/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Tags/List/Ordered list"), NULL, tag_insert_exec, TAG_OL, ""},
	{N_ ("/Tags/List/Unordered list"), NULL, tag_insert_exec, TAG_UL, ""},
	{N_ ("/Tags/List/List item"), NULL, tag_insert_exec, TAG_LI, ""},
	{N_ ("/Tags/List/sep16"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Tags/List/Data definition"), NULL, tag_insert_exec, TAG_DD, ""},
	{N_ ("/Tags/List/Data term"), NULL, tag_insert_exec, TAG_DT, ""},
	{N_ ("/Tags/List/Descriptive list"), NULL, tag_insert_exec, TAG_DL, ""},
	{N_ ("/Tags/List/sep17"), NULL, NULL, 0, "<Separator>"},
	{N_ ("/Tags/List/Directory list"), NULL, tag_insert_exec, TAG_DIR, ""},
	{N_ ("/Tags/List/Menu"), NULL, tag_insert_exec, TAG_MENU, ""},

	{N_ ("/Tags/Frames"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Tags/Frames/fr"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Tags/Frames/Frame"), NULL, tag_insert_exec, TAG_FRAME, ""},
	{N_ ("/Tags/Frames/Frameset"), NULL, tag_insert_exec, TAG_FRAMESET, ""},
	{N_ ("/Tags/Frames/Iframe"), NULL, tag_insert_exec, TAG_IFRAME, ""},
	{N_ ("/Tags/Frames/No frames"), NULL, tag_insert_exec, TAG_NOFRAMES, ""},
	{N_ ("/Tags/Frames/Base Href"), NULL, tag_insert_exec, TAG_BASE_HREF, ""},

	{N_ ("/_Options"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Options/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Options/Text Editable"), NULL, text_toggle_editable, 0, "<ToggleItem>"},
	{N_ ("/Options/Text Wordwrapped"), NULL, text_toggle_word_wrap, 0, "<ToggleItem>"},
	{N_ ("/Options/Toggle help bar"), NULL, tab_window_toggle, 0, "<ToggleItem>"},
	{N_ ("/Options/Preferences..."), NULL, display_preferences_dialog, 0, ""},

	{N_ ("/_Windows"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Windows/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Windows/New window"), NULL, new_window, 0, NULL},
	{N_ ("/Windows/Start a terminal"), "<control>T", terminal, 0, NULL},
	{N_ ("/Windows/Tip..."), NULL, display_tip_window, 0, NULL},
	{N_ ("/Windows/Preview"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Windows/Preview/t1"), NULL, NULL, 0, "<Tearoff>"},
#ifdef HAVE_LIBGTKXMHTML
	{N_ ("/Windows/Preview/Internal previewer"), NULL, int_view, 0, ""},
#endif
	{N_ ("/Windows/Preview/Preview with external browser"), NULL, netscape_view, 0, ""},

	{N_ ("/_Help"), NULL, NULL, 0, "<LastBranch>"},
	{N_ ("/Help/t1"), NULL, NULL, 0, "<Tearoff>"},
	{N_ ("/Help/Help..."), "F1", helpwindow, 0, NULL},
	{N_ ("/Help/About..."), "F2", about, 0, NULL},
	{N_ ("/Help/References"), NULL, NULL, 0, "<Branch>"},
	{N_ ("/Help/References/ty"), NULL, about, 0, "<Tearoff>"},
	{N_ ("/Help/References/HTML 4.01 Reference"), NULL, about, 0, ""},
	{N_ ("/Help/References/HTML 3.2 Reference"), NULL, about, 0, ""},
	{N_ ("/Help/References/XML 1.0 Reference"), NULL, about, 0, ""},
	{N_ ("/Help/References/CSS 1.0 Reference"), NULL, about, 0, ""},
};

void get_main_menu (GtkWidget * window, GtkWidget ** menubar)
{
	gint nmenu_items = sizeof (menu_items_base) / sizeof (menu_items_base[0]);
	GtkItemFactory *myitem_factory;
	GtkAccelGroup *myaccel_group;
	GtkItemFactoryEntry menu_items[nmenu_items];
	int i;

#ifdef DEBUG
	fprintf (stderr, "(menu.c) [get_main_menu] start\n");
#endif

	for (i = 0; i < nmenu_items; i++)
	  {
		  menu_items[i].path = _ (menu_items_base[i].path);
		  menu_items[i].accelerator = menu_items_base[i].accelerator;
		  menu_items[i].callback = menu_items_base[i].callback;
		  menu_items[i].callback_action = menu_items_base[i].callback_action;
		  menu_items[i].item_type = menu_items_base[i].item_type;
	  }

	myaccel_group = gtk_accel_group_new ();
	myitem_factory = gtk_item_factory_new (GTK_TYPE_MENU_BAR, "<main>", myaccel_group);
	gtk_item_factory_create_items (myitem_factory, nmenu_items, menu_items, NULL);
	gtk_accel_group_attach (myaccel_group, GTK_OBJECT (window));
	if (menubar)
		*menubar = gtk_item_factory_get_widget (myitem_factory, "<main>");
#ifdef DEBUG
	fprintf (stderr, "(menu.c) [get_main_menu] end\n");
#endif
}
/*
 * fin de getmain_menu() 
 */

void add_menu_item ( GtkWidget *menubar, GtkItemFactoryEntry *menuitem )
{
	GtkItemFactory *item_factory;

#ifdef DEBUG
	fprintf (stderr,"(menu.c) [add_menu_item] start\n");
#endif
	item_factory = gtk_item_factory_from_widget ( menubar );
	gtk_item_factory_create_items ( item_factory, 1, menuitem, (int *)menuitem->callback_action );
#ifdef DEBUG
	fprintf (stderr,"(menu.c) [add_menu_item] end\n");
#endif
}
/*
 * end of add_menu_item
 */
